@@ -98,7 +98,8 @@ typedef enum
 typedef enum 
 {
   TERMINAL_EXIT_CLOSE,
-  TERMINAL_EXIT_RESTART
+  TERMINAL_EXIT_RESTART,
+  TERMINAL_EXIT_HOLD
 } TerminalExitAction;
 
 typedef enum
@@ -304,6 +305,7 @@ gboolean terminal_palette_from_string (const char     *str,
                                        gboolean        warn);
 
 
+void profile_name_entry_notify (TerminalProfile *profile);
 
 G_END_DECLS
 
